#!/bin/bash
#
# $Id: traphandler.sh,v 1.3 2005/12/09 09:01:07 jd Exp $
#
# traphandler.sh - Sort SNMP traps into different files (KISS version)
#                  This enables 'clever' searching with check_log, without
#                  hogging all too much CPU load.
#
# Author: Andreas Ericsson <ae@op5.se>
#
# Copyright (C) 2004 OP5 AB
# All rights reserved.
#
#
# This script should be fed the output of snmptrapd in a pipe.
#
#

## constants (sort of, anyway)
tmpfile=`mktemp -t trap_tmp.XXXXXXXX`
trap "rm -f $tmpfile" INT EXIT
traplog_path="/var/www/html/logs"
traplog_suffix="_snmptraps.log"

##################
# Code block start
#
cat > $tmpfile

# get originating IP
ip=`head -n 1 $tmpfile`
case "$ip" in
	"<UNKNOWN>")
	# Workaround to get around the problem with missing sender IP on CentOS
		ip=$(head -n 2 $tmpfile | tac | head -n 1 \
			 | awk -F [ '{print $2}' | awk -F ] '{print $1}')
		sed -i "s/^<UNKNOWN>$/$ip/" $tmpfile
	;;
	UDP:*)
		# handle a first line such as this:
		# UDP: [127.0.0.1]:58351
		ip=$(echo "$ip" | cut -b7- | sed 's/.:.*//')
	;;
esac

log_file="${traplog_path}/${ip}_${traplog_suffix}"
# strip security info so we can safely display it in the web-interface
sed -e "s/[Tt][Rr][Aa][Pp].*community .*$//g" $tmpfile >> "$log_file"

# separate traps (should be <pre> formatted by MIME-type)
echo "-----" >> $log_file
chown monitor.@@DAEMON_GROUP@ $log_file
